@@ -1,6 +1,5 @@
 """Top-level package for Deep Translator"""
 
-# TODO: Discussion: Do these need to be in __init__.py? Are they intended to be exportable?
 from .google_trans import GoogleTranslator
 from .pons import PonsTranslator
 from .linguee import LingueeTranslator
@@ -13,10 +12,9 @@ from .microsoft import MicrosoftTranslator
 from .papago import PapagoTranslator
 from .libre import LibreTranslator
 
-# TODO: Discussion: These should be declared in setup.cfg, setting them here is redundant
 __author__ = """Nidhal Baccouri"""
 __email__ = 'nidhalbacc@gmail.com'
-__version__ = '1.5.0'
+__version__ = '1.6.1'
 
 __all__ = [
     "GoogleTranslator",
@@ -27,7 +25,8 @@ __all__ = [
     "MicrosoftTranslator",
     "QCRI",
     "DeepL",
-    "LibreTranslator"
+    "LibreTranslator",
+    "PapagoTranslator",
     "single_detection",
     "batch_detection"
-           ]
+    ]
