@@ -131,7 +131,7 @@ class MicrosoftTranslator:
         @return: translated text
         """
         try:
-            with open(path) as f:
+            with open(path, 'r', encoding='utf-8') as f:
                 text = f.read().strip()
             return self.translate(text)
         except Exception as e:
